@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 #
 # Copyright (c) 2012 Mikkel Schubert <MikkelSch@gmail.com>
 #
@@ -20,7 +20,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 #
-import types
 import bisect
 import random
 
@@ -29,16 +28,18 @@ def weighted_sampling(choices, weights, rng=random):
     choices = list(choices)
     weights = list(weights)
     if not weights or (len(weights) != len(choices)):
-        raise ValueError("Choices and probabilities must be non-empty lists "
-                         "of identical length, not lengths %i and %i"
-                         % (len(choices), len(weights)))
+        raise ValueError(
+            "Choices and probabilities must be non-empty lists "
+            "of identical length, not lengths %i and %i" % (len(choices), len(weights))
+        )
 
     total = 0
     totals = []
     for (index, weight) in enumerate(weights, start=1):
         if weight <= 0:
-            raise ValueError("Probablities must be > 0, not %r for weight %i"
-                             % (weight, index))
+            raise ValueError(
+                "Probablities must be > 0, not %r for weight %i" % (weight, index)
+            )
         total += weight
         totals.append(total)
 
@@ -49,12 +50,12 @@ def weighted_sampling(choices, weights, rng=random):
 
 
 def reservoir_sampling(items, downsample_to, rng=random):
-    if not isinstance(downsample_to, (types.IntType, types.LongType)):
-        raise TypeError("Unexpected type for 'downsample_to': %r"
-                        % (type(downsample_to),))
+    if not isinstance(downsample_to, int):
+        raise TypeError(
+            "Unexpected type for 'downsample_to': %r" % (type(downsample_to),)
+        )
     elif downsample_to < 0:
-        raise ValueError("Negative value for 'downsample_to': %i"
-                         % (downsample_to,))
+        raise ValueError("Negative value for 'downsample_to': %i" % (downsample_to,))
 
     reservoir = []
     for (index, item) in enumerate(items):
