@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 #
 # Copyright (c) 2012 Mikkel Schubert <MikkelSch@gmail.com>
 #
@@ -23,40 +23,21 @@
 """Wrapper and utility functions for VCF handling, using
 the VCF data-structures from pysam."""
 
-import re
 import collections
 
 
-_re_tmpl = "(^|;)%s=([^;]+)(;|$)"
-_re_cache = {}
+Indel = collections.namedtuple(
+    "Indel", ["in_reference", "pos", "prefix", "what", "postfix"]
+)
 
 
-def get_info(vcf, field, default = None, type = str):
-    """Returns the value of the specified field from the info column
-    of a VCF record. The type is determined by 'type' parameter, which
-    may be any function. If no matching key is found, or if the key is
-    not associated with a value, the function returns None by default."""
-    try:
-        regexp = _re_cache[field]
-    except KeyError:
-        regexp = _re_cache[field] = re.compile(_re_tmpl % (field,))
-
-    match = regexp.search(vcf.info)
-    if not match:
-        return default
-
-    return type(match.groups()[1])
-
-
-Indel = collections.namedtuple("Indel", ["in_reference", "pos", "prefix", "what", "postfix"])
-
 def parse_indel(vcf):
     """Parses the VCF record of an indel, and returns a tuple containing the
     position (0-based) of the previous base, a boolean indicating whether or
-    not the subsequent sequence is found in the reference sequence, and a 
+    not the subsequent sequence is found in the reference sequence, and a
     string containing the bases added to / removed from the reference.
 
-    Thus (7, False, "ACGT", "AC") indicates that the sequence ACGT has been 
+    Thus (7, False, "ACGT", "AC") indicates that the sequence ACGT has been
     inserted following the 8th nucleotide, compared with the reference, and
     that the insertion is followed by the bases "AC" on the reference."""
     if not is_indel(vcf):
@@ -64,23 +45,25 @@ def parse_indel(vcf):
     elif "," in vcf.alt:
         raise ValueError("VCF records with multiple indels not supported!")
     elif vcf.ref[0] != vcf.alt[0]:
-        raise ValueError("Sequences do not match VCF spec, first base differs: "
-                         "%s:%s -- %s > %s" % (vcf.contig, vcf.pos + 1, vcf.ref, vcf.alt))
+        raise ValueError(
+            "Sequences do not match VCF spec, first base differs: "
+            "%s:%s -- %s > %s" % (vcf.contig, vcf.pos + 1, vcf.ref, vcf.alt)
+        )
 
     ref_len, alt_len = len(vcf.ref), len(vcf.alt)
     # The length of the insertion / deletion
     len_diff = abs(alt_len - ref_len)
 
     # Wheter or not the sequence 'what' is found in the reference
-    in_reference = (ref_len >= alt_len)
+    in_reference = ref_len >= alt_len
 
     # The sequence added or removed from the reference
-    longest = max(vcf.ref, vcf.alt, key = len)
-    shortest = min(vcf.ref, vcf.alt, key = len)
-    what = longest[1:len_diff + 1]
+    longest = max(vcf.ref, vcf.alt, key=len)
+    shortest = min(vcf.ref, vcf.alt, key=len)
+    what = longest[1 : len_diff + 1]
 
     postfix = shortest[1:]
-    if longest[len_diff + 1:] != postfix:
+    if longest[len_diff + 1 :] != postfix:
         raise ValueError("Sequence postfix does not match; malformed indel!")
 
     return Indel(in_reference, vcf.pos, vcf.ref[0], what, postfix)
@@ -92,25 +75,8 @@ def is_indel(vcf):
     return "INDEL" in vcf.info
 
 
-def get_genotype(vcf, sample=0, _re=re.compile(r'[|/]')):
-    """Returns the most likely genotype of a sample in a vcf record. If no
-    single most likely genotype can be determined, the function returns 'N' for
-    both bases."""
-    nucleotides = []
-    nucleotides.extend(vcf.ref.split(","))
-    nucleotides.extend(vcf.alt.split(","))
-
-    result = []
-    for genotype in _re.split(get_format(vcf, sample)["GT"]):
-        result.append(nucleotides[int(genotype)])
-
-    return result
-
-
 # The corresponding nucleotides for each value in the VCF PL field
-_genotype_indices = [(jj, ii)
-                     for ii in range(0, 10)
-                     for jj in range(0, ii + 1)]
+_genotype_indices = [(jj, ii) for ii in range(0, 10) for jj in range(0, ii + 1)]
 
 
 def get_ml_genotype(vcf, sample=0):
@@ -121,22 +87,23 @@ def get_ml_genotype(vcf, sample=0):
     genotypes.extend(vcf.ref.split(","))
     genotypes.extend(vcf.alt.split(","))
 
-    PL = map(int, get_format(vcf, sample)["PL"].split(","))
+    PL = list(map(int, get_format(vcf, sample)["PL"].split(",")))
 
     if len(PL) == len(genotypes):
         ploidy = 1
     else:
         expected_length = (len(genotypes) * (len(genotypes) + 1)) // 2
         if len(PL) != expected_length:
-            raise ValueError("Expected %i PL values, found %i"
-                         % (expected_length, len(PL)))
+            raise ValueError(
+                "Expected %i PL values, found %i" % (expected_length, len(PL))
+            )
         ploidy = 2
 
     if PL.count(min(PL)) > 1:
         # No single most likely genotype
         return ("N", "N")
 
-    most_likely = min(xrange(len(PL)), key=PL.__getitem__)
+    most_likely = min(range(len(PL)), key=PL.__getitem__)
     if ploidy == 1:
         prefix = postfix = most_likely
     else:
@@ -146,5 +113,4 @@ def get_ml_genotype(vcf, sample=0):
 
 
 def get_format(vcf, sample=0):
-    return dict(zip(vcf.format.split(":"),
-                    vcf[sample].split(":")))
+    return dict(zip(vcf.format.split(":"), vcf[sample].split(":")))
