@@ -46,12 +46,14 @@ _COMMANDS = {
     "cleanup": "paleomix.tools.cleanup",
     "coverage": "paleomix.tools.coverage",
     "depths": "paleomix.tools.depths",
+    "dupcheck": "paleomix.tools.dupcheck",
     # VCF/etc. tools
     "rmdup_collapsed": "paleomix.tools.rmdup_collapsed",
     "vcf_filter": "paleomix.tools.vcf_filter",
     "vcf_to_fasta": "paleomix.tools.vcf_to_fasta",
     # Misc tools
     ":validate_fastq": "paleomix.tools.validate_fastq",
+    ":rscript": "paleomix.tools.rscript",
 }
 
 
