@@ -61,13 +61,16 @@ class ValidateBAMNode(PicardNode):
         builder = picard_command(config, "ValidateSamFile")
         _set_max_open_files(builder, "MAX_OPEN_TEMP_FILES")
 
-        if True or big_genome_mode:
+        if big_genome_mode:
             self._configure_for_big_genome(config, builder)
 
         builder.set_option("I", "%(IN_BAM)s", sep="=")
         for check in ignored_checks:
             builder.add_option("IGNORE", check, sep="=")
 
+        # Exhaustive index validation is expensive and doesn't add a whole lot
+        builder.add_option("INDEX_VALIDATION_STRINGENCY", "LESS_EXHAUSTIVE", sep="=")
+
         output_log = output_log or swap_ext(input_bam, ".validated")
         builder.set_kwargs(
             IN_BAM=input_bam, IN_INDEX=input_index, OUT_STDOUT=output_log
