@@ -26,7 +26,7 @@ import os
 import pysam
 
 import paleomix
-import paleomix.resources
+from paleomix.common import resources
 
 from paleomix.node import Node
 
@@ -35,10 +35,11 @@ import paleomix.common.fileutils as fileutils
 import paleomix.pipelines.zonkey.parts.admixture as admixture
 import paleomix.pipelines.zonkey.parts.nuclear as nuclear
 
-from paleomix.pipelines.zonkey.common import RSCRIPT_VERSION, read_summary
+from paleomix.pipelines.zonkey.common import read_summary
 
 from paleomix.nodes.samtools import SAMTOOLS_VERSION
 from paleomix.nodes.raxml import RAXML_VERSION
+from paleomix.tools.factory import RSCRIPT_VERSION
 
 
 class ReportNode(Node):
@@ -108,8 +109,10 @@ class ReportNode(Node):
             os.path.join(temp, "report.html"), os.path.join(self._root, "report.html")
         )
 
-        css_path = paleomix.resources.report("zonkey", "report.css")
-        fileutils.copy_file(css_path, os.path.join(self._root, "report.css"))
+        resources.copy_resource(
+            os.path.join("reports", "zonkey", "report.css"),
+            os.path.join(self._root, "report.css"),
+        )
 
     def _write_intro_and_overview(self, output_handle):
         output_handle.write(_SECTION_HEADER.format(name="intro", title="Introduction"))
