@@ -23,7 +23,7 @@
 import os
 
 import paleomix
-import paleomix.resources
+from paleomix.common import resources
 
 from paleomix.node import Node
 
@@ -83,8 +83,10 @@ class SummaryNode(Node):
             os.path.join(temp, "summary.html"), os.path.join(self._root, "summary.html")
         )
 
-        css_path = paleomix.resources.report("zonkey", "report.css")
-        fileutils.copy_file(css_path, os.path.join(self._root, "summary.css"))
+        resources.copy_resource(
+            os.path.join("reports", "zonkey", "report.css"),
+            os.path.join(self._root, "summary.css"),
+        )
 
     def _build_sidemenu(self):
         lines = []
