@@ -4,8 +4,13 @@ if (length(args) != 1) {
     quit(status=1)
 }
 
+packages <- installed.packages()
+
 for (module in args) {
-    if (!require(module, character.only=TRUE)) {
+    if (!(module %in% packages)) {
+        cat(paste("R module '", module, "' is not installed!\n", sep=''))
+        cat(paste("Please run R and execute the following command:\n\n"))
+        cat(paste("> install.packages('", module, "')\n", sep=''))
         quit(status=1)
     }
 
